<!--
Copyright (C) 2024 Maxwell G <maxwell@gtmx.me>
SPDX-License-Identifier: MIT
-->

# go-vendor-tools

[![CI Badge](https://gitlab.com/gotmax23/go-vendor-tools/badges/main/pipeline.svg)](https://gitlab.com/gotmax23/go-vendor-tools/-/commits/main)

[![Copr build status][copr-badge]][copr-package] (`@go-sig/go-vendor-tools-dev`)

Tools for handling Go library vendoring in Fedora

## Documentation

<https://fedora.gitlab.io/sigs/go/go-vendor-tools/>

## Author

go-vendor-tools was authored by Maxwell G and is maintained by them and the
Fedora Go SIG.

[copr-badge]: https://copr.fedorainfracloud.org/coprs/g/go-sig/go-vendor-tools-dev/package/go-vendor-tools/status_image/last_build.png
[copr-package]: https://copr.fedorainfracloud.org/coprs/g/go-sig/go-vendor-tools-dev/package/go-vendor-tools/
